==> Search-Elasticsearch-Client-7_0-7.712.tar.gz: Search-Elasticsearch-Client-7_0-7.712/lib/Search/Elasticsearch/Client/7_0/Direct/Features.pm <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

package Search::Elasticsearch::Client::7_0::Direct::Features;
$Search::Elasticsearch::Client::7_0::Direct::Features::VERSION = '7.712';
use Moo;
with 'Search::Elasticsearch::Client::7_0::Role::API';
with 'Search::Elasticsearch::Role::Client::Direct';
use namespace::clean;

__PACKAGE__->_install_api('features');

1;

=pod

=encoding UTF-8

=head1 NAME

Search::Elasticsearch::Client::7_0::Direct::Features - Plugin providing Features API for Search::Elasticsearch 7.x

=head1 VERSION

version 7.712

=head2 DESCRIPTION

The full documentation for Features API is available here:
L<https://www.elastic.co/guide/en/elasticsearch/reference/7.12/features-apis.html>

=head1 FOLLOW METHODS

=head2 C<follow()>

    my $response = $es->features->get_features();

=head1 AUTHOR

Enrico Zimuel <enrico.zimuel@elastic.co>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2021 by Elasticsearch BV.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

__END__

# ABSTRACT: Plugin providing Features API for Search::Elasticsearch 7.x

==> Search-Elasticsearch-Client-7_0-7.713.tar.gz: Search-Elasticsearch-Client-7_0-7.713/lib/Search/Elasticsearch/Client/7_0/Direct/Features.pm <==
# Licensed to Elasticsearch B.V. under one or more contributor
# license agreements. See the NOTICE file distributed with
# this work for additional information regarding copyright
# ownership. Elasticsearch B.V. licenses this file to you under
# the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

package Search::Elasticsearch::Client::7_0::Direct::Features;
$Search::Elasticsearch::Client::7_0::Direct::Features::VERSION = '7.713';
use Moo;
with 'Search::Elasticsearch::Client::7_0::Role::API';
with 'Search::Elasticsearch::Role::Client::Direct';
use namespace::clean;

__PACKAGE__->_install_api('features');

1;

=pod

=encoding UTF-8

=head1 NAME

Search::Elasticsearch::Client::7_0::Direct::Features - Features API of Search::Elasticsearch 7.x

=head1 VERSION

version 7.713

=head2 DESCRIPTION

The full documentation for Features API is available here:
L<https://www.elastic.co/guide/en/elasticsearch//reference/master/features-apis.html>

=head1 FOLLOW METHODS

=head2 C<follow()>

    my $response = $es->features->get_features();

=head1 AUTHOR

Enrico Zimuel <enrico.zimuel@elastic.co>

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2021 by Elasticsearch BV.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut

__END__

# ABSTRACT: Features API of Search::Elasticsearch 7.x
